



gimli --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
gimli --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
gimli
IF %ERRORLEVEL% NEQ 0 exit /B 1
gimli --from=m --to=km --data=1,2,3,4,5
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
